<?php
/**

 * the class MyEducationPath implements API functionality for education providers
 * the class requires an API key to work. The key can be get on http://myeducationpath.com 

 */
class MyEducationPath {
	var $apiendpoint='http://dean-dashboard.com/api/';
	var $apikey='';
	var $error='';
	var $errorcode=0;
	var $errorstatus='';
	var $templateid='0';
	var $courseidtype='local';
	var $emailuser=false;
	var $useragent='MyEducationPath.com API PHP client';
	var $debug=0;
	function __construct($apikey='',$apiendpoint = '')
	{
		$this->apikey=$apikey;

		if ($apiendpoint != '') {
			$this->apiendpoint = $apiendpoint;

			if (!preg_match('!/api/?$!',$this->apiendpoint) ) {
				if (substr($this->apiendpoint,-1) != '/') {
					$this->apiendpoint .= '/';
				}
				$this->apiendpoint .= 'api/';
			} elseif (substr($this->apiendpoint,-1) != '/') {
				$this->apiendpoint .= '/';
			}
		}

	}
	protected function debug($str) {
		// do something in child classes
		//echo $str."\n";
	}
	function checkAPIKey(){
		if($this->apikey=='') {
			return false;
		}
		
		$resp = $this->doAPICall('GET','profile/info');
		
		if ($resp && is_object($resp) && $resp->status == 'ok') {
			return true;
		}

		return false;
	}
	protected function doAPICall($method,$url,$data = null,$options = ''){
		$url = $this->apiendpoint.'v2/'.$url;
		
		$this->error='';

		$requestbody = '';
		
		if (is_array($data)) {
			$requestbody = json_encode($data);
		} elseif ($data && $data != '') {
			$requestbody = $data;
		}
		
		if (is_array($options)) {
			array_walk($options, function(&$v, $k) { $v = $k.'='.urlencode($v); });
			$options = implode('&',$options);
		}
		
		if ($options != '') {
			$url .= '?'.$options;
		}
		
		if (!function_exists('curl_init')) {
			$this->error='Uncompleted installation of API client. cUrl not installed.';
			return null;
		}
		$this->debug($url);
		
		$process = curl_init($url);
		
		$headers = array('X-Auth-Token: '.$this->apikey);
		
		if ($method != 'GET' ) {
			$headers[] = 'Content-Type: application/json';
		}
		
		curl_setopt($process, CURLOPT_HTTPHEADER, $headers);

		if ($method != 'GET' ) {
			if ($method == 'POST') {
				curl_setopt($process, CURLOPT_POST, 1);
			} else {
				curl_setopt($process, CURLOPT_CUSTOMREQUEST, $method);
			}
			
			curl_setopt($process, CURLOPT_POSTFIELDS,$requestbody);
			$this->debug('method '.$method);
			$this->debug($requestbody);
		}
		
		curl_setopt($process, CURLOPT_USERAGENT, 'MEP API PHP client');
		
		curl_setopt($process, CURLOPT_CONNECTTIMEOUT, 5);
		curl_setopt($process, CURLOPT_TIMEOUT, 30);
		
		curl_setopt($process, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($process, CURLOPT_FOLLOWLOCATION, 1);
		curl_setopt($process, CURLOPT_SSL_VERIFYPEER, false);
		
		$result = curl_exec($process);
		
		$this->debug($result);
		
		if (curl_errno($process)) {
			$this->error=sprintf('Network error: %s (%s)',curl_error($process),curl_errno($process));
			return null;
		}
		
		curl_close($process);
	
		$r = @json_decode($result);
		//print_r( $r);exit;
		if (!is_object($r) && !is_array($r)) {
			$this->error='Can not parse API response';
			return null;
		}

		if ($r->status != 'ok') {
			$message = (isset($r->statusmessage)) ? $r->statusmessage : $r->message;
			$this->error=$message;
			return null;
		}
		
		return $r;
	}
	function executeAPICall($function,$options=''){
		$url=$this->apiendpoint.$function.'/'.urlencode($this->apikey).'/';
		$url.='?'.$options;
		
		$this->error='';
	
		if($this->debug>0){
			echo $url.'<br>';
		}
		
		if(function_exists('curl_init')){
			  $ch = curl_init();
			  curl_setopt($ch, CURLOPT_URL, $url);
			  curl_setopt($ch, CURLOPT_USERAGENT, $this->useragent);
			  curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
			  curl_setopt($ch, CURLOPT_TIMEOUT, 20);
			  curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 3);
	
			  $result = curl_exec ($ch);
	
			  if (curl_error($ch)) { 
				$this->error=curl_error($ch);
				$result="";
			  } 
			  curl_close ($ch);
		}else{
			  $result=file_get_contents($url);
		}
		if(trim($result)==''){
			if($this->error=='')
				$this->error='API request failed';
			return null;
		}
		if(substr($result,0,1)!='{'){
			$r=new Object();
			$r->status='error';
			$r->message='Wrong API response';
		}else{
			$r=json_decode($result);
		}
		
		$this->errorcode=0;
		if($r->status!='ok'){
			$this->error=$r->message;
			$this->errorstatus=$r->status;
			if($r->status=='error_api_key'){
				$this->errorcode=1;
			}
			return $r;
		}
		return $r;
	}
	function setTemplateID($id){
		$this->templateid=$id;
	}
	function setEmailUser($s){
		$this->emailuser=$s;
	}
	function setCourseType($t){
		if($t!='local') $t='remote';
		$this->courseidtype=$t;
	}
	public function getCertificates($filter = '',$start = 100, $offset = 0){
		$resp = $this->doAPICall('GET','certificates/',null,array('filter'=>$filter,'start'=>$start,'offset'=>$offset));
		
		return $resp->response->certificates;		
	}
	public function getTemplates(){
		$resp = $this->doAPICall('GET','templates/');
		
		return $resp->response->templates;		
	}
	
	public function getCertificate($id){
		$resp=$this->doAPICall('GET','certificates/'.$id.'/certificate');
		return $resp->response->certificate;		
	}
	function checkCourseExistsByRemoteID($id){
		$coursedata=$this->executeAPICall('checkCourse','id='.$id);
		if($coursedata->status!='ok'){
			return false;
		}
		if($coursedata->response->exists=='y') return true;
		return false;
	}
	public function addCertificate($courseid,$email,$name,$date,$code='',$programshort='',$hours='',$enddate='',$grade='',$teacher='',$courseidtype='', $widgets = array()){
		if ($courseidtype == '') {
			$courseidtype = $this->courseidtype;
		}
		
		$data = array(
			'email' => $email,
			'code' => $code,
			'name' => $name,
			'date' => $date,
			'program' => $programshort,
			'programshort' => $programshort,
			'coursehours' => $hours,
			'enddate' => $enddate,
			'grade' => $grade,
			'teacher' => $teacher,
			'templateid' => $this->templateid,
			'courseid' => $courseid,
			'courseidtype' => $courseidtype,
			'widgets' => $widgets
			);
		
		$options = 'emailuser='.($this->emailuser?'y':'n');
		
		$resp = $this->doAPICall("PUT",'certificates/create',$data,$options);
		
		return $resp->response->certificate;
	}
	public function removeCertificate($certificateid){
		
		$resp = $this->doAPICall('DELETE','certificates/'.$certificateid.'/delete/');
		
		return true;
	}
	public function getPrintCertificateLink($certificateid){
		$cert_rec = $this->getCertificate($certificateid);
		
		return $cert_rec->printlink;
	}
	function getVendorInformation($demoimagedata=''){
		$resp=$this->executeAPICall('getAccountInfo',$demoimagedata);

		if($resp->status=='ok') return $resp->response->account;
		return null;
	}
	function getCategories(){
		$resp=$this->executeAPICall('getCategories');
		if($resp->status=='ok') return $resp->response->categories;
		return array();
	}
	function addCourse($importid,$name,$description,$url,$imgurl,$price,$duration,$startdate,$tags,$categories){
		
		$coursedata=$this->executeAPICall('addCourse','id='.$importid.
			'&name='.urlencode($name).
			'&description='.urlencode($description).
			'&weburl='.urlencode($url).
			'&imageurl='.urlencode($imgurl).
			'&price='.urlencode($price).
			'&duration='.urlencode($duration).
			'&startdate='.urlencode($startdate).
			'&tags='.urlencode($tags).
			'&categories='.$categories
			);
		if($coursedata->status!='ok'){
			$this->errorcode=2;
			return null;
		}
		return $coursedata->response->course;
	}
	function getCourse($id,$idtype='local'){
		$resp=$this->executeAPICall('getcourse','id='.$id.'&idtype='.$idtype);
		if($resp->status=='ok') return $resp->response->course;
		return null;
	}
	function commentCourse($courseid,$comment,$commentid,$username){
		$resp=$this->executeAPICall('commentcourse','courseid='.$courseid.'&comment='.urlencode($comment).
			'&commentid='.urlencode($commentid).'&username='.urlencode($username)
			);
		
		if($resp->status=='ok') return $resp->response->comment;
		return false;
	}
	function rateCourse($courseid,$userid,$rating){
		$resp=$this->executeAPICall('ratecourse','courseid='.$courseid.'&userid='.urlencode($userid).'&rating='.urlencode($rating));
		
		if($resp->status=='ok') return true;
		return false;
	}
	function getErrorCode(){
		return $this->errorcode;
	}
}

?>
